@@ -55,6 +55,7 @@ class TableManager:
             'primary_keys':[],
             'keys':[],
             'constraints':[],
+            'indexes':[],
             'content_hash':None,
             'default_insert_data':[],
             'test_insert_data':[],
@@ -190,6 +191,7 @@ class TableManager:
         self.data['unique_keys'] = obj.get_arg(tb,['unique_keys'],[],(list))
         self.data['keys'] = obj.get_arg(tb,['keys'],[],(list))
         self.data['constraints'] = obj.get_arg(tb,['constraints'],[],(list))
+        self.data['indexes'] = obj.get_arg(tb,['indexes'],[],(list))
         # self.data['content_hash'] = obj.get_arg(tb,['content_hash'],csu.gen.to_hash(self.settings['raw_statement']),(str))
         self.data['content_hash'] = obj.get_arg(tb,['content_hash'],None,(str))
         self.data['default_insert_data'] = obj.get_arg(tb,['default_insert_data'],[],(str))
