@@ -872,16 +872,15 @@ def threat():
         `method_name`: threat
         * @xxx [07-21-2022 08:04:40]: documentation for threat
     '''
-
-
     exrex_threats = [
         f"you (could|might|may|will) die (horribly|slowly|by drowning in (chipmunks|hamsters|chainsaws|ferrets|{common_animal()}))",
         f"your (pets|family|friends|family and friends|loved ones) will be (haunted|eaten|stalked|starred at menacingly) by (snail|rabbit|kitten|{common_animal()}) ghosts",
     ]
-    th = _rand_option(exrex_threats)
-    th = _rand_option(list(_exrex.generate(th)))
-    th = th.replace("__RANDOM_ANIMAL__",common_animal())
-    return th
+
+    threat_string = _rand_option(exrex_threats)
+    threat_string = _rand_option(list(_exrex.generate(threat_string)))
+    threat_string = threat_string.replace("__RANDOM_ANIMAL__",common_animal())
+    return threat_string
 
 def gender(bias=100,return_int=False)->str:
     '''
