@@ -129,7 +129,7 @@ def mysql_parse_type_data(value:str):
         "type":None,
         "size":None,
     }
-    
+
     pat = _re.compile(r"([A-Za-z]*)(?:\(([0-9]*)\))?")
     match = _re.findall(pat,value)
     if match is not None:
@@ -141,7 +141,7 @@ def mysql_parse_type_data(value:str):
             data['type'] = type_name
             if len(type_size) > 0:
                 data['size'] = int(type_size)
-                
+
     return data
 
 def gen_mysql_type(name:str,size:int=None):
@@ -186,45 +186,101 @@ def sql_type_to_python(value):
         return _sql_data_types[value]
     return None
 
+
+
+
+
+
+def _parse_statement_comment(value):
+    '''
+        A utility method used to parse the SQL COMMENT 'beepBoopBleepBlorp' portion of a string.
+
+        This is intended for general use on table, column and index statements.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The SQL statement to parse the comment from.
+
+        Return {tuple}
+        ----------------------
+        A tuple containing the value with the comment removed and the comment itself.
+
+        if no comment is found the second indice of the tuple is None: (value,None)
+
+        `example`:\n
+        SQL: \`modified_timestamp\`               int NULL DEFAULT NULL COMMENT 'description: The unix timestamp of when this was last modified, null otherwise.',\n
+        result = ("\`modified_timestamp\`               int NULL DEFAULT NULL","description: The unix timestamp of when this was last modified, null otherwise.")
+
+
+        SQL: ") COMMENT='description: Defines a registration association entity.';"\n
+        result = (")","description: Defines a registration association entity.")
+
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-21-2022 08:59:41
+        `memberOf`: sql_parse
+        `version`: 1.0
+        `method_name`: _parse_statement_comment
+        * @xxx [07-21-2022 09:03:45]: documentation for _parse_statement_comment
+    '''
+
+    # @Mstep [] capture the comment if it is found in the line.
+    comment_value = None
+    match = _re.findall(r"(comment(?:=|\s)\'(.*)$)",value,_re.IGNORECASE)
+    # match = _re.findall(r"(?:(comment(?:=|\s)\'(.*)$)|(\s+comment\s+\'(.*)$))",value,_re.IGNORECASE)
+    # match = _re.findall(r"(comment(?:=|\s)\'(.*)$)",value,_re.IGNORECASE)
+    if match is not None and len(match) > 0:
+        match = list(match[0])
+        comment_value = str(match[1])
+        comment_value = _csu.strip(comment_value,["'",'"',","," ",";"])
+        # print(f"table comment found: {comment_value}")
+        value = value.replace(match[0],"")
+
+    return (value,comment_value)
+
+
+
+
 def parse_column_data(value=None):
-    
+
+
+
+    # @Mstep [] capture the comment if it is found in the line.
+    value, comment_value = _parse_statement_comment(value)
+    # match = _re.findall(r"(\s+comment\s+\'(.*)$)",value,_re.IGNORECASE)
+    # # match = _re.findall(r"(\s+COMMENT\s+([\'\"][^\']*[\'\"]|[0-9\.]))",value,_re.IGNORECASE)
+    # if match is not None and len(match) > 0:
+    #     match = list(match[0])
+    #     comment_value = str(match[1])
+    #     comment_value = _csu.strip(comment_value,["'",'"',","," "])
+    #     value = value.replace(match[0],"")
+
+
     # @Mstep [] capture the default value if it is found in the line.
     default_value = None
-    match = _re.findall(r"(\s+DEFAULT\s+([\'\"][^\']*[\'\"]|[0-9\.]))",value,_re.IGNORECASE)
+    match = _re.findall(r"(\s+default\s+(.*)$)",value,_re.IGNORECASE)
     if match is not None and len(match) > 0:
         match = list(match[0])
-        # print(f"default found: {match}")
-        default_value = match[1]
-        if _re.match(r"^[0-9]*$",match[1]) is not None:
+        default_value = _csu.strip(match[1]," ")
+        
+        if _re.match(r"^[0-9\+-\.]*$",match[1]) is not None:
             default_value = int(match[1])
-        # if _re.match(r"^[0-9\.]+$",match[1]) is not None:
-        #     default_value = float(match[1])
         value = value.replace(match[0],"")
-    
+
     # print(f"value: {value}")
-    
-    
-    # @Mstep [] capture the default value if it is found in the line.
-    comment_value = None
-    match = _re.findall(r"(\s+COMMENT\s+([\'\"][^\']*[\'\"]|[0-9\.]))",value,_re.IGNORECASE)
-    if match is not None and len(match) > 0:
-        match = list(match[0])
-        # print(f"default found: {match}")
-        comment_value = str(match[1])
-        comment_value = _csu.strip(comment_value,["'",'"'])
-        # comment_value = _csu.escape_quoted_chars(comment_value,True)
-        # json = _csu.parse.safe_load_json(comment_value)
-        # if json is not False:
-        #     comment_value = json
-        #     print(f"comment_value: {comment_value}")
-        value = value.replace(match[0],"")
-        
-        
-        
-        
+
+
+
+
+
     # print(f"value: {value}")
-    
-    
+
+
     # value = "`timestamp`       int NULL DEFAULT NULL COMMENT 'Timestamp of when the task was created.' ,"
     _tick,_double_quote,_single_quote,_comma = [Suppress(x) for x in list('`"\',')]
     _quote = (_tick|_double_quote|_single_quote)
@@ -301,7 +357,7 @@ def parse_column_data(value=None):
     return output
 
 def parse_schema_statement(value=None):
-    
+
     # value = "CREATE SCHEMA IF NOT EXISTS `idealech_Equari_Content_Database`;"
 
 
@@ -346,7 +402,12 @@ def parse_schema_statement(value=None):
         output = new_data
     return output
 
-#/ =================================================================================================
+
+
+
+
+
+
 def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
     '''
         Parse a table SQL statement.
@@ -361,7 +422,7 @@ def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
         Return {dict,None}
         ----------------------
         The statement data dictionary if it can be parsed, None otherwise.
-        
+
         {
             `action`: "create",
             `test`: "if not exists",
@@ -419,6 +480,17 @@ def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
     '''
     # _log("sql_parse.parse_table_statement")
 
+    # @Mstep [] capture the comment if it is found in the line.
+    value,comment_value = _parse_statement_comment(value)
+    # match = _re.findall(r"(comment=\'(.*)$)",value,_re.IGNORECASE)
+    # if match is not None and len(match) > 0:
+    #     match = list(match[0])
+    #     comment_value = str(match[1])
+    #     comment_value = _csu.strip(comment_value,["'",'"',","," ",";"])
+    #     # print(f"table comment found: {comment_value}")
+    #     value = value.replace(match[0],"")
+
+
     _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
     _quote = (_tick|_double_quote|_single_quote)
     # _open_paren,_close_paren = [Suppress(x) for x in list('()')]
@@ -449,6 +521,7 @@ def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
             "test":None,
             "schema_name":None,
             "table_name":None,
+            "comment":comment_value,
         }
         new_data = {}
         for k,v in data.items():
@@ -457,16 +530,18 @@ def parse_table_statement(value:_Union[None,str]=None)->_Union[dict,None]:
                 continue
             new_data[k] = v
         new_data = _obj.set_defaults(defaults,new_data)
-        
+
         if new_data['action'] == "create":
             cols = capture_create_table_columns(value)
             # new_data['column_data'] = _obj.strip_list_nulls([parse_column_data(x) for x in cols])
             d = _parse_table_column_lines(cols)
-            new_data["columns"] = d['columns']
-            new_data["primary_keys"] = d['primary_keys']
-            new_data["unique_keys"] = d['unique_keys']
-            new_data["keys"] = d['keys']
-            new_data["constraints"] = d['constraints']
+            new_data = {**new_data,**d}
+            # new_data["columns"] = d['columns']
+            # new_data["primary_keys"] = d['primary_keys']
+            # new_data["unique_keys"] = d['unique_keys']
+            # new_data["keys"] = d['keys']
+            # new_data["constraints"] = d['constraints']
+            new_data["comment"] = comment_value
         # print(new_data)
         output = new_data
 
@@ -476,6 +551,7 @@ def _parse_table_column_lines(lines):
     data = {
         "columns":[],
         "primary_keys":[],
+        "indexes":[],
         "unique_keys":[],
         "keys":[],
         "constraints":[],
@@ -487,7 +563,11 @@ def _parse_table_column_lines(lines):
         if is_line_key(line):
             # print(f"key found: {line} {parse_key(line)}")
             data['keys'] = _lu.append(data['keys'],parse_key(line))
-            
+
+            ft = parse_fulltext_key(line)
+            if ft is not None:
+                data['indexes'].append(ft)
+
             uk = parse_unique_key(line)
             if uk is not None:
                 # print(f"Unique Key Found: {uk}")
@@ -665,7 +745,7 @@ def parse_primary_key(value=None):
 
 
 def parse_unique_key(value=None):
-    
+
     if 'unique key' not in value.lower():
         return None
 # UNIQUE KEY `Unique_barnBlocks_barnID_userID_3006` (`user_id`, `barn_id`) COMMENT 'Unique constraint to ensure a barn cannot block the same user multiple times.',
@@ -693,7 +773,7 @@ def parse_unique_key(value=None):
 
     if len(res) > 0:
         data = res.as_dict()['data']
-        
+
         new_data = {
             "comment":comment
         }
@@ -710,6 +790,60 @@ def parse_unique_key(value=None):
         output = new_data
     return output
 
+def parse_fulltext_key(value=None):
+    # value = "FULLTEXT KEY `FullText_regAss_name_3079` (`name`) COMMENT 'A fullText Index on the registration association name for searching.'"
+
+    value = _re.sub(r'full[^a-z]*text[^a-z]*key','fulltext key',value,_re.IGNORECASE)
+    if 'fulltext key' not in value.lower():
+        return None
+
+    value,comment_value = _parse_statement_comment(value)
+    # print(f"after comment: {value}")
+
+    # FULLTEXT KEY `FullText_regAss_name_3079` (`name`) COMMENT 'A fullText Index on the registration association name for searching.'
+
+    _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
+    _quote = (_tick|_double_quote|_single_quote)
+    _open_paren,_close_paren = [Suppress(x) for x in list('()')]
+    # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+
+    # matches : `FullText_regAss_name_3079`
+    quoted_word = _quote + Word(alphanums + "_") + _quote
+
+
+    paren_word_list = _open_paren + Word(alphanums + "_,'\"` ") + _close_paren
+    column_list = paren_word_list.setResultsName('columns').setParseAction(_parse_list)
+    key_name = quoted_word.setResultsName('constraint_name')
+
+    # comment = None
+    # match = _re.findall(r"comment\s*'([^']*)",value,_re.IGNORECASE)
+    # if isinstance(match,(list)) and len(match) > 0:
+    #     comment = match[0]
+
+    grammar = Suppress(CaselessKeyword('fulltext key')) + key_name + column_list
+    res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
+
+    output = None
+
+    if len(res) > 0:
+        data = res.as_dict()['data']
+
+        new_data = {
+            "comment":comment_value
+        }
+
+        for k,v in data.items():
+            if k == "columns":
+                new_data[k] = v.split(",")
+                continue
+            if isinstance(v,(list)):
+                new_data[k] = v[0]
+                continue
+            new_data[k] = v
+        # print(f"fulltext Key Data: {new_data}")
+        # print(new_data)
+        output = new_data
+    return output
 
 def parse_constraint(value:str):
     '''
@@ -763,11 +897,11 @@ def parse_constraint(value:str):
     res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
 
     output = None
-    
+
     comment = None
     match = _re.findall(r"comment\s*'([^']*)",value,_re.IGNORECASE)
     if isinstance(match,(list)) and len(match) > 0:
-        comment = match[0]    
+        comment = match[0]
 
     if len(res) > 0:
         data = res.as_dict()['data']
@@ -784,373 +918,217 @@ def parse_constraint(value:str):
         output = new_data
     return output
 
-def parse_table_columns(sql):
-    '''
-        Parses an SQL create file into a list of column dictionaries.
 
-        ----------
+# def parse_allow_null(col_data):
+#     '''
+#         Determines if the column is allowed to be null.
 
-        Arguments
-        -------------------------
-        `sql` {str}
-            The sql to parse or a file path to parse.
+#         ----------
 
-        Keyword Arguments
-        -------------------------
-        `arg_name` {type}
-                arg_description
+#         Arguments
+#         -------------------------
+#         `col_data` {dict}
+#             The column_data dictionary produced by parse_table_columns
+#             Must include the shlexed property.
 
-        Return {type}
-        ----------------------
-        return_description
+#         Return {dict}
+#         ----------------------
+#         The col_data dictionary with an updated allow_nulls property.
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:59:37
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: parse_table_columns
-        # @TODO []: documentation for parse_table_columns
-    '''
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 05-31-2022 07:29:36
+#         `memberOf`: TableManager
+#         `version`: 1.0
+#         `method_name`: parse_allow_null
+#         @xxx [05-31-2022 07:31:12]: documentation for parse_allow_null
+#     '''
 
-    if _f.exists(sql):
-        sql = _f.readr(sql)
-    file_data = strip_keys_constraints(sql)
-    file_data['columns'] = {}
+#     nn_found = False
+#     for s in col_data['shlexed']:
+#         if _csu.array_in_string(["not null","NOT NULL"],s,False):
+#             nn_found = True
+#     if nn_found is False:
+#         col_data['allow_nulls'] = True
+#     return col_data
 
-    cols = {}
-    parsed = _sqlparse.parse(file_data['sql'])
-    for stmt in parsed:
-        # Get all the tokens except whitespaces
-        tokens = [t for t in _sqlparse.sql.TokenList(stmt.tokens) if t.ttype != _sqlparse.tokens.Whitespace]
-        is_create_stmt = False
-        for _, token in enumerate(tokens):
-            # Is it a create statements ?
-            if token.match(_sqlparse.tokens.DDL, 'CREATE'):
-                is_create_stmt = True
-                continue
+# def parse_col_comment(col_data):
+#     '''
+#         Captures a comment related to the column.
 
-            # If it was a create statement and the current token starts with "("
-            if is_create_stmt and token.value.startswith("("):
-                # Get the table name by looking at the tokens in reverse order till you find
-                # a token with None type
-                # print (f"table: {get_table_name(tokens[:i])}")
+#         ----------
 
-                # Now parse the columns
-                txt = token.value
-                # strip_indices(txt)
-                # print("\n\n")
-                columns = txt[1:txt.rfind(")")].replace("\n","").split(",")
-                # print(columns)
-                # print("\n\n")
-                for column in columns:
-                    c = ' '.join(column.split()).split()
-                    # print(c)
-                    if len(c) == 0:
-                        continue
-                    c_name = c[0].replace('\"',"")
-                    c_name = c_name.replace('`','')
-                    # c_type = c[1]  # For condensed type information
-                    # OR
-                    c_type = " ".join(c[1:]) # For detailed type informatio
-                    data = {
-                        "name":c_name,
-                        "raw_type":c_type,
-                        "default":None,
-                        "size":None,
-                        "allow_nulls":False,
-                        "data_type":None,
-                        "comment":None,
-                        "shlexed":None,
-                        "is_primary_key":False,
-                        "is_unique":False,
-                    }
-                    # print (f"raw_type: {data['raw_type']}")
-                    data['shlexed'] = _shlex.split(data['raw_type'])
-                    data = prep_shlexed(data)
-                    # print (f"column: {c_name}")
-                    if data['name'] in file_data['primary_keys']:
-                        data['is_primary_key'] = True
-                    
-                    data = parse_col_type(data)
-                    data = parse_allow_null(data)
-                    data = parse_col_comment(data)
+#         Arguments
+#         -------------------------
+#         `col_data` {dict}
+#             The column_data dictionary produced by parse_table_columns
+#             Must include the shlexed property.
 
 
+#         Return {dict}
+#         ----------------------
+#         The col_data dictionary with an updated comment property.
 
-                    # del data['shlexed']
-                    cols[c_name] = data
-                # print ("---"*20)
-                break
-    # cols = determine_primary_column(cols)
-    file_data['columns'] = cols
-    # cfu.write.to_json("tmp.sql.delete.json",file_data)
-    return file_data
-
-def prep_shlexed(col_data):
-    '''
-        Prepares the shlexed property for parsing by combining indices as necessary.
-
-        ----------
-
-        Arguments
-        -------------------------
-        `col_data` {dict}
-            The column_data dictionary produced by parse_table_columns
-            Must include the shlexed property.
-
-        Return {dict}
-        ----------------------
-        The col_data dictionary with an updated shlexed property.
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 05-31-2022 07:52:33
+#         `memberOf`: TableManager
+#         `version`: 1.0
+#         `method_name`: parse_col_comment
+#         @xxx [05-31-2022 07:53:42]: documentation for parse_col_comment
+#     '''
 
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:55:19
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: prep_shlexed
-        @xxx [05-31-2022 07:56:12]: documentation for prep_shlexed
-    '''
+#     for s in col_data['shlexed']:
+#         # s = s.lower()
+#         # print(f"s: {s}")
+#         if s.lower().startswith('comment'):
+#             # _re.replace(r'^comment\s*')
+#             cmt = s.replace('comment','')
+#             cmt = _sql.escape_quoted_chars(cmt,True)
+#             col_data['comment'] = _csu.strip(cmt,[" "])
+#             break
+
+#     return col_data
+
+# def parse_col_type(col_data):
+#     '''
+#         Parses the SQL column type from the column data.
+
+#         ----------
+
+#         Arguments
+#         -------------------------
+#         `col_data` {dict}
+#             The column_data dictionary produced by parse_table_columns
+#             Must include the shlexed property.
+
+#         Return {dict}
+#         ----------------------
+#         The col_data dictionary with an updated data_type property.
 
 
-    output = []
-    previous_val = None
-    # print(f"col_data['shlexed']: {col_data['shlexed']}")
-    for _,d in enumerate(col_data['shlexed']):
-        dl = d.lower()
-        if previous_val == "not" and dl == "null":
-            output[-1] = "not null"
-            continue
-        if previous_val == "default":
-            output[-1] = f"default {d}"
-            continue
-        if previous_val == "comment":
-            output[-1] = f"comment {d}"
-            continue
-        if col_data['name'] == 'PRIMARY':
-            if previous_val == "key":
-                output[-1] = f"key {d}"
-                continue
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 05-31-2022 07:54:14
+#         `memberOf`: TableManager
+#         `version`: 1.0
+#         `method_name`: parse_col_type
+#         @xxx [05-31-2022 07:54:59]: documentation for parse_col_type
+#     '''
 
-        #     if col_data['schlexed']
-        output.append(d)
-        previous_val = dl
-    col_data['shlexed'] = output
-    return col_data
+#     for t in col_data['shlexed']:
+#         for sql_type in _sql_data_types:
+#             if sql_type in t.lower():
+#                 col_data['data_type'] = sql_type
+#                 break
 
-def parse_allow_null(col_data):
-    '''
-        Determines if the column is allowed to be null.
+#         col_data['size'] = parse_column_size(t)
+#         break
+#     # lower_raw = col_data['raw_type'].lower()
+#     # for t in _sql_data_types:
+#     #     if lower_raw.startswith(t):
+#     #         # print(f"data type: {t}")
+#     #         col_data['data_type'] = t
+#     #         break
+#     return col_data
 
-        ----------
+# def parse_column_size(type_string):
+#     '''
+#         Called by parse_col_type
+#         This will capture the column size if the type supports it.
 
-        Arguments
-        -------------------------
-        `col_data` {dict}
-            The column_data dictionary produced by parse_table_columns
-            Must include the shlexed property.
+#         ----------
 
-        Return {dict}
-        ----------------------
-        The col_data dictionary with an updated allow_nulls property.
+#         Arguments
+#         -------------------------
+#         `type_string` {str}
+#             The type of the column, example: "varchar(500)"
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:29:36
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: parse_allow_null
-        @xxx [05-31-2022 07:31:12]: documentation for parse_allow_null
-    '''
+#         Return {int|None}
+#         ----------------------
+#         The integer size of the column upon success, None otherwise.
 
-    nn_found = False
-    for s in col_data['shlexed']:
-        if _csu.array_in_string(["not null","NOT NULL"],s,False):
-            nn_found = True
-    if nn_found is False:
-        col_data['allow_nulls'] = True
-    return col_data
-
-def parse_col_comment(col_data):
-    '''
-        Captures a comment related to the column.
-
-        ----------
-
-        Arguments
-        -------------------------
-        `col_data` {dict}
-            The column_data dictionary produced by parse_table_columns
-            Must include the shlexed property.
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 05-31-2022 07:26:51
+#         `memberOf`: TableManager
+#         `version`: 1.0
+#         `method_name`: parse_column_size
+#         @xxx [05-31-2022 07:28:25]: documentation for parse_column_size
+#     '''
 
 
-        Return {dict}
-        ----------------------
-        The col_data dictionary with an updated comment property.
+#     lower_raw = type_string.lower()
+#     for sc in _sql_types_with_sizes:
+#         if sc in lower_raw:
+#             pat = _re.compile(sc+r"\(([0-9]*)\)")
+#             match = _re.findall(pat,lower_raw)
+#             if match is not None:
+#                 if len(match) > 0:
+#                     return int(match[0])
+#     return None
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:52:33
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: parse_col_comment
-        @xxx [05-31-2022 07:53:42]: documentation for parse_col_comment
-    '''
+# def strip_keys_constraints(sql):
+#     output = {
+#         "sql":[],
+#         "keys":[],
+#         "constraints":[],
+#     }
+#     lines = sql.split("\n")
+#     for line in lines:
+#         if len(line) == 0 or is_line_comment(line):
+#             continue
+#         line = _sql.escape_quoted_commas(line)
+#         # print(f"line: {line}")
+#         if is_line_key(line):
+#             output['keys'].append(line)
+#             continue
+#         if is_line_constraint(line):
+#             output['constraints'].append(line)
+#             continue
+#         # match = _re.findall(r'^(\w+\s*)?key',line,_re.IGNORECASE)
+#         # match = _re.findall(r'^((\w+\s*)?key|constraint)',line,_re.IGNORECASE)
+#         output['sql'].append(line)
+#     output['sql'] = '\n'.join(output['sql'])
 
+#     if len(output['keys']) > 0:
+#         primary_keys = []
+#         unique_keys = []
+#         for k in output['keys']:
+#             data = parse_primary_keys(k)
+#             if len(data) > 0:
+#                 primary_keys = data
+#                 continue
 
-    for s in col_data['shlexed']:
-        # s = s.lower()
-        # print(f"s: {s}")
-        if s.lower().startswith('comment'):
-            # _re.replace(r'^comment\s*')
-            cmt = s.replace('comment','')
-            cmt = _sql.escape_quoted_chars(cmt,True)
-            col_data['comment'] = _csu.strip(cmt,[" "])
-            break
+#             uk_data = parse_unique_key(k)
+#             if uk_data is not None:
+#                 print(f"Unique Key successfully parsed.")
+#                 unique_keys.append(uk_data)
+#                 continue
+#         output['primary_keys'] = primary_keys
+#         output['unique_keys'] = unique_keys
 
-    return col_data
+#     if len(output['constraints']) > 0:
+#         foreign_keys = []
+#         for k in output['constraints']:
+#             data = parse_constraint(k)
+#             if data is not None:
+#                 foreign_keys.append(data)
+#                 continue
 
-def parse_col_type(col_data):
-    '''
-        Parses the SQL column type from the column data.
+#             data = parse_key(k)
+#             if data is not None:
+#                 foreign_keys.append(data)
+#                 continue
 
-        ----------
+#         output['foreign_keys'] = foreign_keys
 
-        Arguments
-        -------------------------
-        `col_data` {dict}
-            The column_data dictionary produced by parse_table_columns
-            Must include the shlexed property.
-
-        Return {dict}
-        ----------------------
-        The col_data dictionary with an updated data_type property.
-
-
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:54:14
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: parse_col_type
-        @xxx [05-31-2022 07:54:59]: documentation for parse_col_type
-    '''
-
-    for t in col_data['shlexed']:
-        for sql_type in _sql_data_types:
-            if sql_type in t.lower():
-                col_data['data_type'] = sql_type
-                break
-
-        col_data['size'] = parse_column_size(t)
-        break
-    # lower_raw = col_data['raw_type'].lower()
-    # for t in _sql_data_types:
-    #     if lower_raw.startswith(t):
-    #         # print(f"data type: {t}")
-    #         col_data['data_type'] = t
-    #         break
-    return col_data
-
-def parse_column_size(type_string):
-    '''
-        Called by parse_col_type
-        This will capture the column size if the type supports it.
-
-        ----------
-
-        Arguments
-        -------------------------
-        `type_string` {str}
-            The type of the column, example: "varchar(500)"
-
-        Return {int|None}
-        ----------------------
-        The integer size of the column upon success, None otherwise.
-
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 05-31-2022 07:26:51
-        `memberOf`: TableManager
-        `version`: 1.0
-        `method_name`: parse_column_size
-        @xxx [05-31-2022 07:28:25]: documentation for parse_column_size
-    '''
-
-
-    lower_raw = type_string.lower()
-    for sc in _sql_types_with_sizes:
-        if sc in lower_raw:
-            pat = _re.compile(sc+r"\(([0-9]*)\)")
-            match = _re.findall(pat,lower_raw)
-            if match is not None:
-                if len(match) > 0:
-                    return int(match[0])
-    return None
-
-def strip_keys_constraints(sql):
-    output = {
-        "sql":[],
-        "keys":[],
-        "constraints":[],
-    }
-    lines = sql.split("\n")
-    for line in lines:
-        if len(line) == 0 or is_line_comment(line):
-            continue
-        line = _sql.escape_quoted_commas(line)
-        # print(f"line: {line}")
-        if is_line_key(line):
-            output['keys'].append(line)
-            continue
-        if is_line_constraint(line):
-            output['constraints'].append(line)
-            continue
-        # match = _re.findall(r'^(\w+\s*)?key',line,_re.IGNORECASE)
-        # match = _re.findall(r'^((\w+\s*)?key|constraint)',line,_re.IGNORECASE)
-        output['sql'].append(line)
-    output['sql'] = '\n'.join(output['sql'])
-
-    if len(output['keys']) > 0:
-        primary_keys = []
-        unique_keys = []
-        for k in output['keys']:
-            data = parse_primary_keys(k)
-            if len(data) > 0:
-                primary_keys = data
-                continue
-
-            uk_data = parse_unique_key(k)
-            if uk_data is not None:
-                print(f"Unique Key successfully parsed.")
-                unique_keys.append(uk_data)
-                continue
-        output['primary_keys'] = primary_keys
-        output['unique_keys'] = unique_keys
-
-    if len(output['constraints']) > 0:
-        foreign_keys = []
-        for k in output['constraints']:
-            data = parse_constraint(k)
-            if data is not None:
-                foreign_keys.append(data)
-                continue
-
-            data = parse_key(k)
-            if data is not None:
-                foreign_keys.append(data)
-                continue
-
-        output['foreign_keys'] = foreign_keys
-
-    return output
+#     return output
 
 def is_line_key(line:str)->bool:
     '''
@@ -1177,7 +1155,6 @@ def is_line_key(line:str)->bool:
         * @xxx [06-05-2022 20:17:55]: documentation for is_line_key
     '''
 
-
     match = _re.match(r'^(\w+\s*)?key',line,_re.IGNORECASE)
     if match is not None:
         return True
@@ -1434,9 +1411,10 @@ def parse(sql):
             continue
 
         data['statements'].append(state)
-    # datastring = _json.dumps(data)
-    # data = _json.loads(_sql.escape_quoted_chars(datastring,True))
+
     for tb in data['tables']:
+        if tb['comment'] is not None:
+            tb['comment'] = _sql.escape_quoted_chars(tb['comment'],True)
         if 'columns' in tb:
             for col in tb['columns']:
                 if col['comment'] is not None:
